@@ -437,48 +437,6 @@ optimal_sizes <- function( x, hspans = "none" ){
        heights = apply(heights, 1, max, na.rm = TRUE) )
 }
 
-#' @importFrom officer table_layout table_width table_colwidths prop_table
-#' @export
-#' @title Global table properties
-#' @description Set table layout and table width. Default to fixed
-#' algorithm.
-#'
-#' If layout is fixed, column widths will be used to display the table;
-#' `width` is ignored.
-#'
-#' If layout is autofit, column widths will not be used;
-#' table width is used (as a percentage).
-#' @note
-#' PowerPoint output ignore 'autofit layout'.
-#' @param x flextable object
-#' @param layout 'autofit' or 'fixed' algorithm. Default to 'autofit'.
-#' @param width The parameter has a different effect depending on the
-#' output format. Users should consider it as a minimum width.
-#' In HTML, it is the minimum width of the space that the
-#' table should occupy. In Word, it is a preferred size and Word
-#' may decide not to strictly stick to it. It has no effect on
-#' PowerPoint and PDF output. Its default value is 0, as an effect, it
-#' only use necessary width to display all content. It is not used by the
-#' PDF output.
-#' @examples
-#' library(flextable)
-#' ft_1 <- qflextable(head(cars))
-#' ft_2 <- set_table_properties(ft_1, width = .5, layout = "autofit")
-#' ft_2
-#' @family flextable dimensions
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_set_table_properties_1.png}{options: width="100"}}
-#'
-#' \if{html}{\figure{fig_set_table_properties_2.png}{options: width="400"}}
-set_table_properties <- function(x, layout = "fixed", width = 0){
-
-  stopifnot(layout %in% c("fixed", "autofit"))
-  stopifnot(is.numeric(width), width <= 1)
-
-  x$properties <- list(layout = layout, width = width)
-  x
-}
 
 # utils ----
 #' @importFrom stats reshape
@@ -568,6 +526,12 @@ text_metric <- function(x) {
   dimnames(extents_values) <- list(NULL, c("width", "height"))
 
   txt_data <- cbind(txt_data, extents_values)
+
+  # swap width/height when cell is rotated
+  td_data <- as.data.frame(x$styles$cells)[, c("ft_row_id", "col_id", "text.direction")]
+  txt_data <- merge(txt_data, td_data, by = c("ft_row_id", "col_id"))
+  txt_data[txt_data$text.direction %in% c("tbrl","btlr"), c("width", "height") := list(.SD$height, .SD$width)]
+
   txt_data <- txt_data[, c(list(width = sum(.SD$width, na.rm = TRUE), height = max(.SD$height, na.rm = TRUE))),
     by = c("ft_row_id", "fake_row_id", "col_id")
   ]
