@@ -17,29 +17,6 @@ check_formula_i_and_part <- function(i, part){
   TRUE
 }
 
-
-#' @importFrom xml2 xml_attr<-
-process_url <- function(rel, url, str, pattern, double_esc = TRUE){
-
-  if(double_esc)
-    escape <- function(x) htmlEscape(htmlEscape(x))
-  else escape <- function(x) htmlEscape(x)# it seems that word does not behave as powerpoint
-
-
-  doc <- as_xml_document(str)
-  for(url_ in url){
-    new_rid <- sprintf("rId%.0f", rel$get_next_id())
-    rel$add(
-      id = new_rid, type = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/hyperlink",
-      target = escape(url_), target_mode = "External" )
-
-    linknodes <- xml_find_all(doc, paste0("//", pattern, "[@r:id=", shQuote(url_), "]"))
-    xml_attr(linknodes, "r:id") <- new_rid
-  }
-
-  as.character(doc)
-}
-
 absolute_path <- function(x){
 
   if (length(x) != 1L)
@@ -93,6 +70,46 @@ format_double <- function(x, digits = 2){
   formatC(x, format = "f", digits = digits, decimal.mark = ".", drop0trailing = TRUE )
 }
 
+has_value <- function(x) {
+  !is.null(x) && !is.na(x) && length(x) == 1
+}
+
+coalesce_options <- function(a = NULL, b = NULL) {
+  if (is.null(a)) {
+    return(b)
+  }
+  if (is.null(b)) {
+    return(a)
+  }
+  if (length(b) == 1) {
+    b <- rep(b, length(a))
+  }
+  out <- a
+  out[!has_value(a)] <- b[!has_value(a)]
+  out
+}
+
+mcoalesce_options <- function(...) {
+  Reduce(coalesce_options, list(...))
+}
+
+safe_stat <- function(..., FUN = max, NA_value = NA_real_) {
+  x <- na.omit(unlist(list(...)))
+  if (length(x) > 0) {
+    FUN(x)
+  } else {
+    NA_value
+  }
+}
+
+safe_stat_ext <- function(..., FUN = max, NA_value = NA_real_, LENGTH = NULL) {
+  x <- na.omit(unlist(list(...)))
+  if (length(x) > 0 && (!is.numeric(LENGTH) || length(LENGTH) == 0 || is.na(LENGTH) || length(x) == LENGTH[1])) {
+    FUN(x)
+  } else {
+    NA_value
+  }
+}
 
 # metric units -----
 cm_to_inches <- function(x) {
