@@ -35,10 +35,9 @@ test_that("word_document2 captions", {
 
   style_nodes <- xml_find_all(x, "/w:document/w:body/w:tbl/preceding-sibling::*[1]/w:pPr/w:pStyle[@w:val='TableCaption']")
   expect_length(style_nodes, 2)
-  txt_nodes <- xml_find_all(x, "/w:document/w:body/w:tbl/preceding-sibling::*[1]/w:r/w:t")
+  txt_nodes <- xml_find_all(x, "/w:document/w:body/w:tbl/preceding-sibling::*[1]")
   expect_equal(
-    sum(xml_text(txt_nodes) %in% "a table caption"),
-    2
+    xml_text(txt_nodes), c("Table 1: a table caption", "Table 2: a table caption")
   )
 })
 
@@ -50,7 +49,7 @@ test_that("html_document2 captions", {
          output_file = "caption.html", quiet = TRUE)
 
   doc <- read_html(file.path(dirname(rmd_file), "caption.html"))
-  captions_ids <- xml_find_all(doc, "//table/caption//span")
+  captions_ids <- xml_find_all(doc, "//table/caption/span[@id]")
   expect_equal(xml_attr(captions_ids, "id"), c("tab:table1", "tab:table2"))
   txt <- gsub("[\n\r]+", "", xml_text(xml_find_all(doc, "//table/caption")))
   expect_equal(txt, c("Table 1: a table caption", "Table 2: a table caption"))
@@ -85,11 +84,7 @@ test_that("word_document captions", {
   x <- read_xml(xml_file)
 
 
-  xml_find_all(x, "/w:document/w:body/w:tbl/preceding-sibling::w:p[1]/w:bookmarkStart[@w:name='table1']")
   bookmarks <- xml_find_all(x, "/w:document/w:body/w:tbl/preceding-sibling::w:p[1]/w:bookmarkStart")
-  expect_length(bookmarks, 2)
-  expect_equal(xml_attr(bookmarks, "name"), c("table1", "mtcars"))
-  wordfields <- xml_find_all(x, "/w:document/w:body/w:tbl/preceding-sibling::w:p[1]/w:r/w:instrText")
-  expect_equal(xml_text(wordfields), c("SEQ tab \\* Arabic", "SEQ tab \\* Arabic"))
+  expect_length(bookmarks, 0)
 })
 
